part of sonarr_commands;

/// Facilitates, encapsulates, and manages individual calls related to `command` within Sonarr.
/// 
/// [SonarrCommandHandler_Command] internally handles routing the HTTP client to the API calls.
class SonarrCommandHandler_Command {
    final Dio _client;

    /// Create a series command handler using an initialized [Dio] client.
    SonarrCommandHandler_Command(this._client);

    /// Handler for [command (RefreshSeries)](https://github.com/Sonarr/Sonarr/wiki/Command#refreshseries).
    /// 
    /// Refresh series information from trakt and rescan disk.
    /// If no `seriesId` is supplied, all series are refreshed.
    /// 
    /// Optional Parameters:
    /// - `seriesId`: Series ID for the series to refresh
    Future<SonarrCommand> refreshSeries({
        int seriesId,
    }) async => _commandRefreshSeries(_client, seriesId: seriesId);

    /// Handler for [command (RescanSeries)](https://github.com/Sonarr/Sonarr/wiki/Command#rescanseries).
    /// 
    /// Refresh rescan disk for a single series.
    /// If no `seriesId` is supplied, all series are rescanned.
    /// 
    /// Optional Parameters:
    /// - `seriesId`: Series ID for the series to refresh
    Future<SonarrCommand> rescanSeries({
        int seriesId,
    }) async => _commandRescanSeries(_client, seriesId: seriesId);
}
