import 'dart:convert';
import 'package:json_annotation/json_annotation.dart';

part 'command_body.g.dart';

/// Model for the body for executing a command in Sonarr.
@JsonSerializable(explicitToJson: true)
class SonarrCommandBody {
    /// Series ID attached to the command (if applicable, else null).
    @JsonKey(name: 'seriesId')
    int seriesId;

    @JsonKey(name: 'isNewSeries')
    bool isNewSeries;

    @JsonKey(name: 'sendUpdatesToClient')
    bool sendUpdatesToClient;

    @JsonKey(name: 'updateScheduledTask')
    bool updateScheduledTask;

    @JsonKey(name: 'completionMessage')
    String completionMessage;

    @JsonKey(name: 'requiresDiskAccess')
    bool requiresDiskAccess;

    @JsonKey(name: 'isExclusive')
    bool isExclusive;

    @JsonKey(name: 'name')
    String name;

    @JsonKey(name: 'trigger')
    String trigger;

    @JsonKey(name: 'suppressMessages')
    bool suppressMessages;

    SonarrCommandBody({
        this.seriesId,
        this.isNewSeries,
        this.sendUpdatesToClient,
        this.updateScheduledTask,
        this.completionMessage,
        this.requiresDiskAccess,
        this.isExclusive,
        this.name,
        this.trigger,
        this.suppressMessages,
    });

    /// Returns a JSON-encoded string version of this object.
    @override
    String toString() => json.encode(this.toJson());

    /// Deserialize a JSON map to a [SonarrCommandBody] object.
    factory SonarrCommandBody.fromJson(Map<String, dynamic> json) => _$SonarrCommandBodyFromJson(json);
    /// Serialize a [SonarrCommandBody] object to a JSON map.
    Map<String, dynamic> toJson() => _$SonarrCommandBodyToJson(this);
}
